@@ -2,7 +2,6 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-import sys
 import pytest
 
 
@@ -12,11 +11,7 @@ from cachecontrol.filewrapper import CallbackFileWrapper
 from requests import Session
 
 
-class Test39(object):
-
-    @pytest.mark.skipif(
-        sys.version.startswith("2"), reason="Only run this for python 3.x"
-    )
+class Test39:
     def test_file_cache_recognizes_consumed_file_handle(self, url):
         s = CacheControl(Session(), FileCache("web_cache"))
         the_url = url + "cache_60"
