@@ -2,15 +2,14 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from datetime import datetime
+from datetime import datetime, timezone
+from unittest.mock import Mock
 
-from mock import Mock
 from cachecontrol.caches import RedisCache
 
 
-class TestRedisCache(object):
-
-    def setup(self):
+class TestRedisCache:
+    def setup_method(self):
         self.conn = Mock()
         self.cache = RedisCache(self.conn)
 
@@ -18,6 +17,10 @@ class TestRedisCache(object):
         self.cache.set("foo", "bar", expires=datetime(2014, 2, 2))
         assert self.conn.setex.called
 
+    def test_set_expiration_datetime_aware(self):
+        self.cache.set("foo", "bar", expires=datetime(2014, 2, 2, tzinfo=timezone.utc))
+        assert self.conn.setex.called
+
     def test_set_expiration_int(self):
         self.cache.set("foo", "bar", expires=600)
         assert self.conn.setex.called
