@@ -4,9 +4,10 @@ Shared utility classes.
 
 from requests.structures import CaseInsensitiveDict
 
+from cachecontrol.serialize import Serializer
 
-class NullSerializer(object):
 
+class NullSerializer(Serializer):
     def dumps(self, request, response, body=None):
         return response
 
@@ -18,6 +19,7 @@ class NullSerializer(object):
 
 class DummyResponse:
     """Match a ``urllib3.response.HTTPResponse``."""
+
     version = "1.1"
     reason = b"Because"
     strict = 0
